import React, { useState, useEffect } from "react";
import { Container } from "@/components/ui/container";
import { motion } from "framer-motion";
import { Button } from "@/components/ui/button";
import { useReveal } from "@/hooks/use-reveal";
import { Settings, Calculator } from "lucide-react";
import CostSavingsCalculator from "@/components/CostSavingsCalculator";

// Step data for How It Works section
const steps = [
  {
    number: "1",
    title: "Configure",
    description: "Set up your travel policy and preferences once, then never worry about it again. Recurro learns how your team travels.",
    icon: (
      <svg className="w-5 h-5" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
        <path d="M9.3 20C9.7 20.4 10.4 20.4 10.8 20L20.6 10.2C21 9.8 21 9.1 20.6 8.7L15.3 3.4C14.9 3 14.2 3 13.8 3.4L4 13.2C3.6 13.6 3.6 14.3 4 14.7L9.3 20Z" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
        <path d="M12.8999 5.3999L18.5999 11.0999" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
        <path d="M3 21H21" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
      </svg>
    ),
    iconBg: "bg-[#7B61FF]",
    badge: "One-time setup",
    badgeTag: "SIMPLE",
  },
  {
    number: "2",
    title: "Generate",
    description: "Easily create trip packages for your team with just a few clicks. Recurro automatically handles all the details.",
    icon: (
      <svg className="w-5 h-5" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
        <path d="M8 12H16M12 16V8M22 12C22 17.5228 17.5228 22 12 22C6.47715 22 2 17.5228 2 12C2 6.47715 6.47715 2 12 2C17.5228 2 22 6.47715 22 12Z" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
      </svg>
    ),
    iconBg: "bg-[#7B61FF]",
    badge: "Fast deployment",
  },
  {
    number: "3",
    title: "Manage",
    description: "Track all your team travel in one place with powerful admin tools and real-time analytics dashboards.",
    icon: (
      <svg className="w-5 h-5" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
        <path d="M10.6 13.4C9.93333 13.7556 9.17778 14 8.4 14C6.07111 14 4.2 12.1289 4.2 9.8C4.2 7.47111 6.07111 5.6 8.4 5.6C9.17778 5.6 9.93333 5.84444 10.6 6.2M10.6 13.4C11.4222 13.7556 12.3556 14 13.4 14C14.4444 14 15.3778 13.7556 16.2 13.4M10.6 13.4V6.2M10.6 6.2C11.4222 5.84444 12.3556 5.6 13.4 5.6C15.7289 5.6 17.6 7.47111 17.6 9.8C17.6 12.1289 15.7289 14 13.4 14M8.4 9.8H13.4" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
        <path d="M10.6 18.2H15.6M18.2 18.2H20M4.2 18.2H7.6" stroke="currentColor" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round"/>
      </svg>
    ),
    iconBg: "bg-[#7B61FF]",
    badge: "Real-time spending analytics",
  },
];

// Benefit data
const benefits = [
  {
    title: "92% Time Savings",
    description: "Minutes, not hours. Let automation handle the details.",
    iconPath: "M12 8V12L15 15M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z"
  },
  {
    title: "18% Cost Savings",
    description: "Policy enforcement and price optimization.",
    iconPath: "M3 6L11 2L21 6M3 6L11 10M3 6V18L11 22M21 6L11 10M21 6V18L11 22M11 10V22"
  },
  {
    title: "Proactive Support",
    description: "Instant alerts and smart rebooking options.",
    iconPath: "M13 10V3L4 14H11V21L20 10H13Z"
  },
  {
    title: "Maximum Rewards",
    description: "Optimize loyalty programs across teams.",
    iconPath: "M9 12L11 14L15 10M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z"
  },
  {
    title: "Frictionless Workflows",
    description: "One system, zero headaches. Automated approvals and instant syncing.",
    iconPath: "M13.5 4.5L21 12L13.5 19.5M10.5 19.5L3 12L10.5 4.5"
  },
  {
    title: "Loyalty Maximizer",
    description: "Capture and optimize every point, upgrade, and status benefit.",
    iconPath: "M9 12L11 14L15 10M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z"
  }
];

export default function BenefitsGrid() {
  // State for the active tab
  const [activeTab, setActiveTab] = useState('benefits');
  
  // Debug: Log tab changes
  useEffect(() => {
    console.log('Active tab changed to:', activeTab);
  }, [activeTab]);
  
  return (
    <section id="benefits-and-how-it-works" className="py-12 md:py-20 relative bg-white">
      {/* Enhanced gradient transition from hero section to benefits */}
      <div className="absolute inset-x-0 top-0 h-40 bg-gradient-to-b from-[#F9F7FF] to-white -z-10"></div>
      
      {/* Very subtle top connector */}
      <div className="absolute top-0 left-0 w-full h-px bg-gray-50"></div>
      
      <Container className="px-6 md:px-8">
        <div className="text-center relative mb-8">
          {/* Removed redundant title */}
          
          <h2 className="text-3xl md:text-4xl font-medium text-gray-900 mb-6 leading-tight">
            The <span className="text-[#7B61FF] relative">
              Recurro
              <span className="absolute bottom-1 left-0 w-full h-[0.12em] bg-[#7B61FF]/20 rounded-full"></span>
            </span> Advantage
          </h2>
          
          {/* Decorative thin line with accent */}
          <div className="flex items-center justify-center mb-6">
            <div className="h-[1px] w-16 bg-gradient-to-r from-transparent to-[#7B61FF]/30"></div>
            <div className="h-1.5 w-1.5 rounded-full bg-[#7B61FF] mx-2"></div>
            <div className="h-[1px] w-16 bg-gradient-to-l from-transparent to-[#7B61FF]/30"></div>
          </div>
        </div>
        
        {/* Tabbed navigation for Benefits, How It Works, and Savings Estimator */}
        <div className="flex justify-center mb-10">
          {/* Mobile tabs (stacked for better spacing) - With Web3 style glassmorphism */}
          <div className="md:hidden flex flex-col w-full max-w-[240px] mx-auto space-y-2">
            <button 
              onClick={() => setActiveTab('benefits')}
              className={`relative px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 overflow-hidden ${
                activeTab === 'benefits' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'backdrop-blur-sm bg-white/50 text-gray-600 border border-white/30 shadow-md'
              }`}
            >
              {activeTab === 'benefits' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">Benefits</span>
            </button>
            <button 
              onClick={() => setActiveTab('how-it-works')}
              className={`relative px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 overflow-hidden ${
                activeTab === 'how-it-works' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'backdrop-blur-sm bg-white/50 text-gray-600 border border-white/30 shadow-md'
              }`}
            >
              {activeTab === 'how-it-works' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">How It Works</span>
            </button>
            <button 
              onClick={() => setActiveTab('calculator')}
              className={`relative px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 overflow-hidden ${
                activeTab === 'calculator' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'backdrop-blur-sm bg-white/50 text-gray-600 border border-white/30 shadow-md'
              }`}
            >
              {activeTab === 'calculator' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">Savings Estimator</span>
            </button>
          </div>
          
          {/* Desktop tabs (horizontal pills) - With Web3 style glassmorphism */}
          <div className="hidden md:inline-flex backdrop-blur-sm bg-white/50 rounded-full p-1.5 
              shadow-md border border-white/30">
            <button 
              onClick={() => setActiveTab('benefits')}
              className={`relative px-5 py-2 rounded-full text-sm font-medium transition-all duration-300 min-w-[90px] overflow-hidden ${
                activeTab === 'benefits' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'text-gray-600 hover:bg-white/70 hover:shadow-sm'
              }`}
            >
              {activeTab === 'benefits' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">Benefits</span>
            </button>
            <button 
              onClick={() => setActiveTab('how-it-works')}
              className={`relative px-5 py-2 rounded-full text-sm font-medium transition-all duration-300 min-w-[120px] overflow-hidden ${
                activeTab === 'how-it-works' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'text-gray-600 hover:bg-white/70 hover:shadow-sm'
              }`}
            >
              {activeTab === 'how-it-works' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">How It Works</span>
            </button>
            <button 
              onClick={() => setActiveTab('calculator')}
              className={`relative px-5 py-2 rounded-full text-sm font-medium transition-all duration-300 min-w-[120px] overflow-hidden ${
                activeTab === 'calculator' 
                  ? 'bg-gradient-to-r from-[#7B61FF] to-[#8A74FF] text-white shadow-[0_4px_12px_rgba(123,97,255,0.2)]' 
                  : 'text-gray-600 hover:bg-white/70 hover:shadow-sm'
              }`}
            >
              {activeTab === 'calculator' && (
                <span className="absolute inset-0 w-full h-full bg-gradient-to-r from-transparent via-white/20 to-transparent animate-[shimmer_1.5s_infinite] -translate-x-full"></span>
              )}
              <span className="relative z-10">Savings Estimator</span>
            </button>
          </div>
        </div>
        
        {/* Tab content */}
        <div className="mt-8">
          {/* Benefits tab content */}
          {activeTab === 'benefits' && (
            <div>
              {/* Benefits Header */}
              <div className="max-w-3xl mx-auto mb-12">
                <div className="flex flex-col items-center">
                  <div className="flex items-center justify-center mb-4">
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                    <span className="text-sm text-[#7B61FF] uppercase tracking-wider font-medium mx-3">KEY BENEFITS</span>
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                  </div>
                  
                  <h3 className="text-2xl md:text-3xl font-medium text-gray-900 text-center mb-4">
                    Why teams choose <span className="text-[#7B61FF] relative font-serif">Recurro</span>
                  </h3>
                  
                  <p className="mt-2 text-base text-gray-600 leading-relaxed text-center max-w-2xl mx-auto">
                    Unlock massive efficiency with our streamlined travel coordination platform
                  </p>
                  
                  {/* Decorative thin line with accent */}
                  <div className="flex items-center justify-center mt-6">
                    <div className="h-[1px] w-16 bg-gradient-to-r from-transparent to-[#7B61FF]/30"></div>
                    <div className="h-1.5 w-1.5 rounded-full bg-[#7B61FF] mx-2"></div>
                    <div className="h-[1px] w-16 bg-gradient-to-l from-transparent to-[#7B61FF]/30"></div>
                  </div>
                </div>
              </div>
              
              {/* Mobile: 2x2 Grid layout for first 4 benefits */}
              <div className="md:hidden">
                <div className="grid grid-cols-2 gap-3 mb-4">
                  {benefits.slice(0, 4).map((benefit, index) => (
                    <div key={index} className="bg-white rounded-xl shadow-sm p-5 border border-gray-100 flex flex-col items-center justify-center text-center">
                      <div className="w-14 h-14 bg-[#7B61FF] rounded-full flex items-center justify-center mb-3 shadow-sm">
                        <svg width="26" height="26" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                          <path d={benefit.iconPath} stroke="white" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                        </svg>
                      </div>
                      <h3 className="text-lg font-medium text-gray-900">
                        {index === 0 ? "Time Savings" : 
                         index === 1 ? "Cost Savings" :
                         index === 2 ? "Proactive Support" :
                         index === 3 ? "Maximum Rewards" : benefit.title}
                      </h3>
                    </div>
                  ))}
                </div>
                
                {/* More benefits in same style as the first 4 */}
                <div className="grid grid-cols-2 gap-3">
                  {benefits.slice(4, 6).map((benefit, index) => (
                    <div key={index + 4} className="bg-white rounded-xl shadow-sm p-5 border border-gray-100 flex flex-col items-center justify-center text-center">
                      <div className="w-14 h-14 bg-[#7B61FF] rounded-full flex items-center justify-center mb-3 shadow-sm">
                        <svg width="26" height="26" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                          <path d={benefit.iconPath} stroke="white" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                        </svg>
                      </div>
                      <h3 className="text-lg font-medium text-gray-900">
                        {index === 0 ? "Frictionless Workflows" : "Loyalty Program"}
                      </h3>
                    </div>
                  ))}
                </div>
              </div>
              
              {/* Desktop: Traditional grid layout */}
              <div className="hidden md:grid md:grid-cols-3 gap-6">
                <div className="backdrop-blur-sm bg-white rounded-xl p-8 border border-gray-100/60 transition-all duration-500 
                  hover:shadow-[0_10px_25px_rgba(123,97,255,0.15)] 
                  shadow-[0_4px_15px_rgba(123,97,255,0.05)] 
                  hover:translate-y-[-4px] relative overflow-hidden">
                  {/* Web3-style grid pattern */}
                  <div className="absolute inset-0 opacity-5 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4zIi8+PC9zdmc+')]"></div>
                  
                  <div className="w-14 h-14 backdrop-blur-sm bg-[#7B61FF]/10 rounded-2xl flex items-center justify-center mb-5
                    shadow-[0_4px_15px_rgba(123,97,255,0.1)] border border-white/40">
                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                      <path d="M12 8V12L15 15M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                    </svg>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3">Time Savings</h3>
                  <p className="text-gray-600">
                    Minutes, not hours. Smart automation handles the details while you focus on what matters.
                  </p>
                </div>
                
                <div className="backdrop-blur-sm bg-white rounded-xl p-8 border border-gray-100/60 transition-all duration-500 
                  hover:shadow-[0_10px_25px_rgba(123,97,255,0.15)] 
                  shadow-[0_4px_15px_rgba(123,97,255,0.05)] 
                  hover:translate-y-[-4px] relative overflow-hidden">
                  {/* Web3-style grid pattern */}
                  <div className="absolute inset-0 opacity-5 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4zIi8+PC9zdmc+')]"></div>
                  
                  <div className="w-14 h-14 backdrop-blur-sm bg-[#7B61FF]/10 rounded-2xl flex items-center justify-center mb-5
                    shadow-[0_4px_15px_rgba(123,97,255,0.1)] border border-white/40">
                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                      <path d="M3 6L11 2L21 6M3 6L11 10M3 6V18L11 22M21 6L11 10M21 6V18L11 22M11 10V22" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                    </svg>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3">Cost Savings</h3>
                  <p className="text-gray-600">
                    Automatic policy enforcement, loyalty maximization, and price optimization—all with complete transparency.
                  </p>
                </div>
                
                <div className="backdrop-blur-sm bg-white rounded-xl p-8 border border-gray-100/60 transition-all duration-500 
                  hover:shadow-[0_10px_25px_rgba(123,97,255,0.15)] 
                  shadow-[0_4px_15px_rgba(123,97,255,0.05)] 
                  hover:translate-y-[-4px] relative overflow-hidden">
                  {/* Web3-style grid pattern */}
                  <div className="absolute inset-0 opacity-5 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4zIi8+PC9zdmc+')]"></div>
                  
                  <div className="w-14 h-14 backdrop-blur-sm bg-[#7B61FF]/10 rounded-2xl flex items-center justify-center mb-5
                    shadow-[0_4px_15px_rgba(123,97,255,0.1)] border border-white/40">
                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                      <path d="M13 10V3L4 14H11V21L20 10H13Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                    </svg>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3">Proactive Support</h3>
                  <p className="text-gray-600">
                    Instant alerts, intelligent alternatives, and seamless rebooking when plans change. One step ahead, always.
                  </p>
                </div>
              </div>
              
              <div className="hidden md:grid md:grid-cols-2 gap-6 mt-6">
                <div className="backdrop-blur-sm bg-white/70 rounded-xl p-7 border border-white/20 transition-all duration-500 
                  hover:shadow-[0_10px_25px_rgba(123,97,255,0.15)] 
                  shadow-[0_4px_15px_rgba(123,97,255,0.05)] 
                  hover:translate-y-[-4px] relative overflow-hidden">
                  {/* Web3-style grid pattern */}
                  <div className="absolute inset-0 opacity-5 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4zIi8+PC9zdmc+')]"></div>
                  
                  <div className="flex items-center mb-5 relative z-10">
                    <div className="w-12 h-12 backdrop-blur-sm bg-[#7B61FF]/10 rounded-xl flex items-center justify-center mr-4
                      shadow-[0_4px_15px_rgba(123,97,255,0.1)] border border-white/40">
                      <svg className="text-[#7B61FF]" width="22" height="22" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M13.5 4.5L21 12L13.5 19.5M10.5 19.5L3 12L10.5 4.5" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                      </svg>
                    </div>
                    <h3 className="text-xl font-medium text-gray-900 font-serif">Frictionless Workflows</h3>
                  </div>
                  <p className="text-gray-600 leading-relaxed pl-16 relative z-10">
                    One system, zero headaches. Automated approvals, instant syncing, and perfect integration with your existing tools.
                  </p>
                </div>
                
                <div className="backdrop-blur-sm bg-white/70 rounded-xl p-7 border border-white/20 transition-all duration-500 
                  hover:shadow-[0_10px_25px_rgba(123,97,255,0.15)] 
                  shadow-[0_4px_15px_rgba(123,97,255,0.05)] 
                  hover:translate-y-[-4px] relative overflow-hidden">
                  {/* Web3-style grid pattern */}
                  <div className="absolute inset-0 opacity-5 bg-[url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjAiIGhlaWdodD0iMjAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGNpcmNsZSBjeD0iMSIgY3k9IjEiIHI9IjEiIGZpbGw9IiM3QjYxRkYiIGZpbGwtb3BhY2l0eT0iMC4zIi8+PC9zdmc+')]"></div>
                  
                  <div className="flex items-center mb-5 relative z-10">
                    <div className="w-12 h-12 backdrop-blur-sm bg-[#7B61FF]/10 rounded-xl flex items-center justify-center mr-4
                      shadow-[0_4px_15px_rgba(123,97,255,0.1)] border border-white/40">
                      <svg className="text-[#7B61FF]" width="22" height="22" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M9 12L11 14L15 10M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                      </svg>
                    </div>
                    <h3 className="text-xl font-medium text-gray-900 font-serif">Loyalty Maximizer</h3>
                  </div>
                  <p className="text-gray-600 leading-relaxed pl-16 relative z-10">
                    Every point, upgrade, and status benefit—captured and optimized across your team. Full visibility, zero waste.
                  </p>
                </div>
              </div>
            </div>
          )}
          
          {/* Calculator tab content */}
          {activeTab === 'calculator' && (
            <div>
              {/* Calculator Header - Matching other tabs but with minimal bottom margin */}
              <div className="max-w-3xl mx-auto mb-0">
                <div className="flex flex-col items-center">
                  <div className="flex items-center justify-center mb-3">
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                    <span className="text-sm text-[#7B61FF] uppercase tracking-wider font-medium mx-3">SAVINGS ESTIMATOR</span>
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                  </div>
                  
                  <h3 className="text-2xl md:text-3xl font-medium text-gray-900 text-center mb-3">
                    Estimate your <span className="text-[#7B61FF] relative font-serif">savings</span>
                  </h3>
                  
                  <p className="mt-1 text-base text-gray-600 leading-relaxed text-center max-w-2xl mx-auto mb-2">
                    See how much value your organization could gain by using Recurro
                  </p>
                  
                  {/* Decorative thin line with accent */}
                  <div className="flex items-center justify-center mb-1">
                    <div className="h-[1px] w-16 bg-gradient-to-r from-transparent to-[#7B61FF]/30"></div>
                    <div className="h-1.5 w-1.5 rounded-full bg-[#7B61FF] mx-2"></div>
                    <div className="h-[1px] w-16 bg-gradient-to-l from-transparent to-[#7B61FF]/30"></div>
                  </div>
                </div>
              </div>
              
              {/* The calculator component */}
              <CostSavingsCalculator />
            </div>
          )}
          
          {/* How It Works tab content */}
          {activeTab === 'how-it-works' && (
            <div>
              <div className="max-w-3xl mx-auto mb-12">
                <div className="flex flex-col items-center">
                  <div className="flex items-center justify-center mb-4">
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                    <span className="text-sm text-[#7B61FF] uppercase tracking-wider font-medium mx-3">3 SIMPLE STEPS</span>
                    <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
                  </div>
                  
                  <h3 className="text-2xl md:text-3xl font-medium text-gray-900 text-center mb-4">
                    Configure once <span className="text-[#7B61FF] relative font-serif">→</span> Click once
                  </h3>
                  
                  <p className="mt-2 text-base text-gray-600 leading-relaxed text-center max-w-2xl mx-auto">
                    Recurro turns hours of travel coordination into minutes
                  </p>
                  
                  {/* Decorative thin line with accent */}
                  <div className="flex items-center justify-center mt-6">
                    <div className="h-[1px] w-16 bg-gradient-to-r from-transparent to-[#7B61FF]/30"></div>
                    <div className="h-1.5 w-1.5 rounded-full bg-[#7B61FF] mx-2"></div>
                    <div className="h-[1px] w-16 bg-gradient-to-l from-transparent to-[#7B61FF]/30"></div>
                  </div>
                </div>
              </div>
              
              {/* Mobile: Vertical stacked layout for steps - Centered design with hanging numbers */}
              <div className="md:hidden space-y-6 py-2 mt-4">
                {/* Step 1 - Mobile - Centered numbers half on/half off the card */}
                <div className="relative pt-6 px-4 pb-3">
                  <div className="absolute left-1/2 -translate-x-1/2 -top-0 z-10">
                    <div className="w-12 h-12 bg-[#7B61FF] rounded-full flex items-center justify-center text-white
                      shadow-[0_4px_12px_rgba(123,97,255,0.2)]">
                      <span className="font-bold text-lg">1</span>
                    </div>
                  </div>
                  <div className="bg-white rounded-xl p-5 pt-8 border border-gray-100
                    shadow-[0_4px_12px_rgba(123,97,255,0.08)] text-center">
                    <h3 className="text-base font-medium text-gray-900 mb-1.5 font-serif">Configure</h3>
                    <p className="text-gray-500 text-sm leading-relaxed">
                      Set up travel policy once, Recurro learns your preferences.
                    </p>
                  </div>
                </div>
                
                {/* Step 2 - Mobile */}
                <div className="relative pt-6 px-4 pb-3">
                  <div className="absolute left-1/2 -translate-x-1/2 -top-0 z-10">
                    <div className="w-12 h-12 bg-[#7B61FF] rounded-full flex items-center justify-center text-white
                      shadow-[0_4px_12px_rgba(123,97,255,0.2)]">
                      <span className="font-bold text-lg">2</span>
                    </div>
                  </div>
                  <div className="bg-white rounded-xl p-5 pt-8 border border-gray-100
                    shadow-[0_4px_12px_rgba(123,97,255,0.08)] text-center">
                    <h3 className="text-base font-medium text-gray-900 mb-1.5 font-serif">Generate</h3>
                    <p className="text-gray-500 text-sm leading-relaxed">
                      Create trip packages with few clicks, Recurro handles details.
                    </p>
                  </div>
                </div>
                
                {/* Step 3 - Mobile */}
                <div className="relative pt-6 px-4 pb-3">
                  <div className="absolute left-1/2 -translate-x-1/2 -top-0 z-10">
                    <div className="w-12 h-12 bg-[#DD9934] rounded-full flex items-center justify-center text-white
                      shadow-[0_4px_12px_rgba(221,153,52,0.2)]">
                      <span className="font-bold text-lg">3</span>
                    </div>
                  </div>
                  <div className="bg-white rounded-xl p-5 pt-8 border border-gray-100
                    shadow-[0_4px_12px_rgba(123,97,255,0.08)] text-center">
                    <h3 className="text-base font-medium text-gray-900 mb-1.5 font-serif">Manage</h3>
                    <p className="text-gray-500 text-sm leading-relaxed">
                      Track all team travel with intuitive dashboards and admin tools.
                    </p>
                  </div>
                </div>
              </div>
              
              {/* Desktop: Original layout - styled to match Benefits cards */}
              <div className="hidden md:grid md:grid-cols-3 gap-6 relative">
                {/* Step 1 */}
                <div className="bg-[#f8f7fc] rounded-xl p-8 border-0 transition-all duration-500 
                  hover:shadow-[8px_8px_16px_rgba(123,97,255,0.03),_-8px_-8px_16px_rgba(255,255,255,0.8)] 
                  shadow-[5px_5px_10px_rgba(123,97,255,0.03),_-5px_-5px_10px_rgba(255,255,255,0.8)] 
                  hover:translate-y-[-4px] flex flex-col">
                  <div className="w-14 h-14 bg-[#F7F0FF] rounded-2xl flex items-center justify-center mb-5
                    shadow-[inset_2px_2px_5px_rgba(123,97,255,0.05),_inset_-2px_-2px_5px_rgba(255,255,255,0.7)]">
                    <div className={`text-[#7B61FF] flex items-center justify-center p-2`}>
                      {steps[0].icon}
                    </div>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3 font-serif">{steps[0].number}. {steps[0].title}</h3>
                  <p className="text-gray-600 leading-relaxed flex-grow">{steps[0].description}</p>
                  
                  {steps[0].badge && (
                    <div className="flex items-center bg-[#F7F0FF] p-2.5 rounded-lg mt-6 shadow-[inset_1px_1px_3px_rgba(123,97,255,0.05),_inset_-1px_-1px_3px_rgba(255,255,255,0.7)]">
                      <div className="w-6 h-6 bg-[#7B61FF] rounded-full text-white flex items-center justify-center text-xs font-bold mr-2 shadow-[1px_1px_3px_rgba(123,97,255,0.1)]">
                        {steps[0].number === "1" ? "TC" : ""}
                      </div>
                      <span className="text-sm font-medium">{steps[0].badge}</span>
                      {steps[0].badgeTag && (
                        <span className="ml-auto bg-[#F0E6FF] text-[#7B61FF] text-xs py-1 px-2 rounded-md shadow-[1px_1px_2px_rgba(123,97,255,0.05)]">
                          {steps[0].badgeTag}
                        </span>
                      )}
                    </div>
                  )}
                </div>
                
                {/* Step 2 */}
                <div className="bg-[#f8f7fc] rounded-xl p-8 border-0 transition-all duration-500 
                  hover:shadow-[8px_8px_16px_rgba(123,97,255,0.03),_-8px_-8px_16px_rgba(255,255,255,0.8)] 
                  shadow-[5px_5px_10px_rgba(123,97,255,0.03),_-5px_-5px_10px_rgba(255,255,255,0.8)] 
                  hover:translate-y-[-4px] flex flex-col">
                  <div className="w-14 h-14 bg-[#F7F0FF] rounded-2xl flex items-center justify-center mb-5
                    shadow-[inset_2px_2px_5px_rgba(123,97,255,0.05),_inset_-2px_-2px_5px_rgba(255,255,255,0.7)]">
                    <div className={`text-[#7B61FF] flex items-center justify-center p-2`}>
                      {steps[1].icon}
                    </div>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3 font-serif">{steps[1].number}. {steps[1].title}</h3>
                  <p className="text-gray-600 leading-relaxed flex-grow">{steps[1].description}</p>
                  
                  {steps[1].badge && (
                    <div className="flex items-center bg-[#F7F0FF] p-2.5 rounded-lg mt-6 shadow-[inset_1px_1px_3px_rgba(123,97,255,0.05),_inset_-1px_-1px_3px_rgba(255,255,255,0.7)]">
                      <div className="w-6 h-6 bg-[#7B61FF] rounded-full text-white flex items-center justify-center text-xs font-bold mr-2 shadow-[1px_1px_3px_rgba(123,97,255,0.1)]">
                        <span className="transform -translate-y-px">⚡</span>
                      </div>
                      <span className="text-sm font-medium">{steps[1].badge}</span>
                    </div>
                  )}
                </div>
                
                {/* Step 3 */}
                <div className="bg-[#f8f7fc] rounded-xl p-8 border-0 transition-all duration-500 
                  hover:shadow-[8px_8px_16px_rgba(123,97,255,0.03),_-8px_-8px_16px_rgba(255,255,255,0.8)] 
                  shadow-[5px_5px_10px_rgba(123,97,255,0.03),_-5px_-5px_10px_rgba(255,255,255,0.8)] 
                  hover:translate-y-[-4px] flex flex-col">
                  <div className="w-14 h-14 bg-[#F7F0FF] rounded-2xl flex items-center justify-center mb-5
                    shadow-[inset_2px_2px_5px_rgba(123,97,255,0.05),_inset_-2px_-2px_5px_rgba(255,255,255,0.7)]">
                    <div className={`text-[#7B61FF] flex items-center justify-center p-2`}>
                      {steps[2].icon}
                    </div>
                  </div>
                  <h3 className="text-2xl font-medium text-gray-900 mb-3 font-serif">{steps[2].number}. {steps[2].title}</h3>
                  <p className="text-gray-600 leading-relaxed flex-grow">{steps[2].description}</p>
                  
                  {steps[2].badge && (
                    <div className="flex items-center bg-[#F7F0FF] p-2.5 rounded-lg mt-6 shadow-[inset_1px_1px_3px_rgba(123,97,255,0.05),_inset_-1px_-1px_3px_rgba(255,255,255,0.7)]">
                      <div className="w-6 h-6 bg-[#7B61FF] rounded-full text-white flex items-center justify-center text-xs font-bold mr-2 shadow-[1px_1px_3px_rgba(123,97,255,0.1)]">
                        {steps[2].number === "3" ? "$" : ""}
                      </div>
                      <span className="text-sm font-medium">{steps[2].badge}</span>
                    </div>
                  )}
                </div>
              </div>
            </div>
          )}
        </div>
      </Container>
    </section>
  );
}